==> haskell-postgresql-simple-0.6.5.1-104-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-postgresql-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 postgresql-simple
version:              0.6.5.1
visibility:           public
id:                   postgresql-simple-0.6.5.1-6bQgq1S2jkeL8RnpDqShGE
key:                  postgresql-simple-0.6.5.1-6bQgq1S2jkeL8RnpDqShGE
license:              BSD-3-Clause
copyright:
    (c) 2011 MailRank, Inc.
    (c) 2011-2018 Leon P Smith
    (c) 2018-2020 Oleg Grenrus

maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Bryan O'\''Sullivan, Leon P Smith
synopsis:             Mid-Level PostgreSQL client library
description:
    Mid-Level PostgreSQL client library, forked from mysql-simple.

category:             Database
abi:                  0138a5fd54b5c41cec728ca1e71463d5
exposed:              True
exposed-modules:
    Database.PostgreSQL.Simple Database.PostgreSQL.Simple.Arrays
    Database.PostgreSQL.Simple.Copy Database.PostgreSQL.Simple.Cursor
    Database.PostgreSQL.Simple.Errors
    Database.PostgreSQL.Simple.FromField
    Database.PostgreSQL.Simple.FromRow
    Database.PostgreSQL.Simple.HStore
    Database.PostgreSQL.Simple.HStore.Internal
    Database.PostgreSQL.Simple.Internal
    Database.PostgreSQL.Simple.LargeObjects
    Database.PostgreSQL.Simple.Newtypes
    Database.PostgreSQL.Simple.Notification
    Database.PostgreSQL.Simple.Ok Database.PostgreSQL.Simple.Range
    Database.PostgreSQL.Simple.SqlQQ Database.PostgreSQL.Simple.Time
    Database.PostgreSQL.Simple.Time.Internal
    Database.PostgreSQL.Simple.ToField Database.PostgreSQL.Simple.ToRow
    Database.PostgreSQL.Simple.Transaction
    Database.PostgreSQL.Simple.TypeInfo
    Database.PostgreSQL.Simple.TypeInfo.Macro
    Database.PostgreSQL.Simple.TypeInfo.Static
    Database.PostgreSQL.Simple.Types Database.PostgreSQL.Simple.Vector
    Database.PostgreSQL.Simple.Vector.Unboxed

hidden-modules:
    Database.PostgreSQL.Simple.Compat
    Database.PostgreSQL.Simple.HStore.Implementation
    Database.PostgreSQL.Simple.Internal.PQResultUtils
    Database.PostgreSQL.Simple.Time.Implementation
    Database.PostgreSQL.Simple.Time.Internal.Parser
    Database.PostgreSQL.Simple.Time.Internal.Printer
    Database.PostgreSQL.Simple.TypeInfo.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/postgresql-simple-0.6.5.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/postgresql-simple-0.6.5.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/postgresql-simple-0.6.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-postgresql-simple
hs-libraries:         HSpostgresql-simple-0.6.5.1-6bQgq1S2jkeL8RnpDqShGE
depends:
    Only-0.1-DItEcvi68ww8z5TVixWVcj
    aeson-2.1.2.1-JZeWX2s1eQL7Ta3HF3w6fW
    attoparsec-0.14.4-K96akOPZKYDKXaMIGNQXgm base-4.18.2.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-LnNRkIvaVf25YvATjz2MZ1
    containers-0.6.7 hashable-1.4.7.0-L2Cc1YdcpYH9U2sZW5osde
    postgresql-libpq-0.9.5.0-6Abcvnlrbx38D8lE6uFyjU
    scientific-0.3.8.0-7SlgUkp6kxxBFUUY5SNCvh template-haskell-2.20.0.0
    text-2.0.2 time-compat-1.9.8-Jxw2UguI3huFXhVcheAJ7
    transformers-0.6.1.0 uuid-types-1.0.6-LOdMhlcFsFOnVrhLe64Jq
    vector-0.13.2.0-JoP5POFPMLsLn1of7TvjGI

haddock-interfaces:
    /usr/share/doc/haskell-postgresql-simple/html/postgresql-simple.haddock

haddock-html:         /usr/share/doc/haskell-postgresql-simple/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-postgresql-simple-0.6.5.1-105-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-postgresql-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 postgresql-simple
version:              0.6.5.1
visibility:           public
id:                   postgresql-simple-0.6.5.1-CtLtgZKsXo2DYyR1VwEidL
key:                  postgresql-simple-0.6.5.1-CtLtgZKsXo2DYyR1VwEidL
license:              BSD-3-Clause
copyright:
    (c) 2011 MailRank, Inc.
    (c) 2011-2018 Leon P Smith
    (c) 2018-2020 Oleg Grenrus

maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Bryan O'\''Sullivan, Leon P Smith
synopsis:             Mid-Level PostgreSQL client library
description:
    Mid-Level PostgreSQL client library, forked from mysql-simple.

category:             Database
abi:                  7e94f13ffdc07e9f064bf26db3c97837
exposed:              True
exposed-modules:
    Database.PostgreSQL.Simple Database.PostgreSQL.Simple.Arrays
    Database.PostgreSQL.Simple.Copy Database.PostgreSQL.Simple.Cursor
    Database.PostgreSQL.Simple.Errors
    Database.PostgreSQL.Simple.FromField
    Database.PostgreSQL.Simple.FromRow
    Database.PostgreSQL.Simple.HStore
    Database.PostgreSQL.Simple.HStore.Internal
    Database.PostgreSQL.Simple.Internal
    Database.PostgreSQL.Simple.LargeObjects
    Database.PostgreSQL.Simple.Newtypes
    Database.PostgreSQL.Simple.Notification
    Database.PostgreSQL.Simple.Ok Database.PostgreSQL.Simple.Range
    Database.PostgreSQL.Simple.SqlQQ Database.PostgreSQL.Simple.Time
    Database.PostgreSQL.Simple.Time.Internal
    Database.PostgreSQL.Simple.ToField Database.PostgreSQL.Simple.ToRow
    Database.PostgreSQL.Simple.Transaction
    Database.PostgreSQL.Simple.TypeInfo
    Database.PostgreSQL.Simple.TypeInfo.Macro
    Database.PostgreSQL.Simple.TypeInfo.Static
    Database.PostgreSQL.Simple.Types Database.PostgreSQL.Simple.Vector
    Database.PostgreSQL.Simple.Vector.Unboxed

hidden-modules:
    Database.PostgreSQL.Simple.Compat
    Database.PostgreSQL.Simple.HStore.Implementation
    Database.PostgreSQL.Simple.Internal.PQResultUtils
    Database.PostgreSQL.Simple.Time.Implementation
    Database.PostgreSQL.Simple.Time.Internal.Parser
    Database.PostgreSQL.Simple.Time.Internal.Printer
    Database.PostgreSQL.Simple.TypeInfo.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/postgresql-simple-0.6.5.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/postgresql-simple-0.6.5.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/postgresql-simple-0.6.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-postgresql-simple
hs-libraries:         HSpostgresql-simple-0.6.5.1-CtLtgZKsXo2DYyR1VwEidL
depends:
    Only-0.1-DItEcvi68ww8z5TVixWVcj
    aeson-2.1.2.1-6DouAcLayfd1cKsM4PdlxR
    attoparsec-0.14.4-IEX5Q72xfrMFJKDYkhuhWv base-4.18.2.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-8vz9c08oERN6HaPlnW3IdE
    containers-0.6.7 hashable-1.4.7.0-2TMrYujL0SWBJEdw6jCOMM
    postgresql-libpq-0.9.5.0-6Abcvnlrbx38D8lE6uFyjU
    scientific-0.3.8.0-JLcC8H5zZSyDPbVdOVmQEk template-haskell-2.20.0.0
    text-2.0.2 time-compat-1.9.8-Ln5uX6BKYFGFxUe2zKnSOu
    transformers-0.6.1.0 uuid-types-1.0.6-7gx1lcEyzTzHtsXguSIhiO
    vector-0.13.2.0-8Ien1418VpU5tGTMA2qRu7

haddock-interfaces:
    /usr/share/doc/haskell-postgresql-simple/html/postgresql-simple.haddock

haddock-html:         /usr/share/doc/haskell-postgresql-simple/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
